CipherWithIdRequestModel

Struct CipherWithIdRequestModel 

pub struct CipherWithIdRequestModel {
Show 26 fields pub encrypted_for: Option<Uuid>, pub encrypted_by_key_id: Option<String>, pub type: Option<CipherType>, pub organization_id: Option<String>, pub folder_id: Option<String>, pub favorite: Option<bool>, pub reprompt: Option<CipherRepromptType>, pub key: Option<String>, pub name: String, pub notes: Option<String>, pub fields: Option<Vec<CipherFieldModel>>, pub password_history: Option<Vec<CipherPasswordHistoryModel>>, pub attachments: Option<HashMap<String, String>>, pub attachments2: Option<HashMap<String, CipherAttachmentModel>>, pub login: Option<Box<CipherLoginModel>>, pub card: Option<Box<CipherCardModel>>, pub identity: Option<Box<CipherIdentityModel>>, pub secure_note: Option<Box<CipherSecureNoteModel>>, pub ssh_key: Option<Box<CipherSshKeyModel>>, pub bank_account: Option<Box<CipherBankAccountModel>>, pub drivers_license: Option<Box<CipherDriversLicenseModel>>, pub passport: Option<Box<CipherPassportModel>>, pub data: Option<String>, pub last_known_revision_date: Option<String>, pub archived_date: Option<String>, pub id: Uuid,
}

Fields

encrypted_for: Option<Uuid>

The Id of the user that encrypted the cipher. It should always represent a UserId.

encrypted_by_key_id: Option<String>

Hex-encoded key id of the user key the client held when it encrypted this cipher. Absent for clients that predate the field. When present, it must match the acting user’s current user key id.

type: Option<CipherType>organization_id: Option<String>folder_id: Option<String>favorite: Option<bool>reprompt: Option<CipherRepromptType>key: Option<String>name: Stringnotes: Option<String>fields: Option<Vec<CipherFieldModel>>password_history: Option<Vec<CipherPasswordHistoryModel>>attachments: Option<HashMap<String, String>>attachments2: Option<HashMap<String, CipherAttachmentModel>>login: Option<Box<CipherLoginModel>>card: Option<Box<CipherCardModel>>identity: Option<Box<CipherIdentityModel>>secure_note: Option<Box<CipherSecureNoteModel>>ssh_key: Option<Box<CipherSshKeyModel>>bank_account: Option<Box<CipherBankAccountModel>>drivers_license: Option<Box<CipherDriversLicenseModel>>passport: Option<Box<CipherPassportModel>>data: Option<String>

JSON string containing cipher-specific data

last_known_revision_date: Option<String>archived_date: Option<String>id: Uuid

Implementations